==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoConnectionInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Mongo Connection
 * @property connectionString ConnectionString to connect to Mongo.
 * @property host Host of mongo connection.
 * @property password Password to connect to Mongo.
 * @property port Port of mongo connection.
 * @property useSsl Whether to UseSsl or UseTls to connect to Mongo. Default is true.
 * @property userName User name to connect to Mongo.
 */
public data class MongoConnectionInformationArgs(
    public val connectionString: Output<String>? = null,
    public val host: Output<String>? = null,
    public val password: Output<String>? = null,
    public val port: Output<Int>? = null,
    public val useSsl: Output<Boolean>? = null,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs =
        com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs.builder()
            .connectionString(connectionString?.applyValue({ args0 -> args0 }))
            .host(host?.applyValue({ args0 -> args0 }))
            .password(password?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .useSsl(useSsl?.applyValue({ args0 -> args0 }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MongoConnectionInformationArgs].
 */
@PulumiTagMarker
public class MongoConnectionInformationArgsBuilder internal constructor() {
    private var connectionString: Output<String>? = null

    private var host: Output<String>? = null

    private var password: Output<String>? = null

    private var port: Output<Int>? = null

    private var useSsl: Output<Boolean>? = null

    private var userName: Output<String>? = null

    /**
     * @param value ConnectionString to connect to Mongo.
     */
    @JvmName("cwpyohatuvwoedvx")
    public suspend fun connectionString(`value`: Output<String>) {
        this.connectionString = value
    }

    /**
     * @param value Host of mongo connection.
     */
    @JvmName("uvlhhhjibsvppssm")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Password to connect to Mongo.
     */
    @JvmName("ejfsulyavccasyqb")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Port of mongo connection.
     */
    @JvmName("uocrjseiduqcwkqc")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Whether to UseSsl or UseTls to connect to Mongo. Default is true.
     */
    @JvmName("rlwmqkukvtfcbspf")
    public suspend fun useSsl(`value`: Output<Boolean>) {
        this.useSsl = value
    }

    /**
     * @param value User name to connect to Mongo.
     */
    @JvmName("fyiutfbnrggrkeoi")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value ConnectionString to connect to Mongo.
     */
    @JvmName("nqrfrmcfqwjvvhcb")
    public suspend fun connectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionString = mapped
    }

    /**
     * @param value Host of mongo connection.
     */
    @JvmName("yujmaualeksdpufb")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Password to connect to Mongo.
     */
    @JvmName("axvcdoosttoetmfb")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Port of mongo connection.
     */
    @JvmName("pfbgtkuxsbqgkxou")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Whether to UseSsl or UseTls to connect to Mongo. Default is true.
     */
    @JvmName("spjonqjhtjkrswim")
    public suspend fun useSsl(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useSsl = mapped
    }

    /**
     * @param value User name to connect to Mongo.
     */
    @JvmName("vrehpvefqwkmmhbu")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): MongoConnectionInformationArgs = MongoConnectionInformationArgs(
        connectionString = connectionString,
        host = host,
        password = password,
        port = port,
        useSsl = useSsl,
        userName = userName,
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoConnectionInformationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Mongo Connection
 * @property connectionString ConnectionString to connect to Mongo.
 * @property host Host of mongo connection.
 * @property password Password to connect to Mongo.
 * @property port Port of mongo connection.
 * @property useSsl Whether to UseSsl or UseTls to connect to Mongo. Default is true.
 * @property userName User name to connect to Mongo.
 */
public data class MongoConnectionInformationArgs(
    public val connectionString: Output<String>? = null,
    public val host: Output<String>? = null,
    public val password: Output<String>? = null,
    public val port: Output<Int>? = null,
    public val useSsl: Output<Boolean>? = null,
    public val userName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs = com.pulumi.azurenative.datamigration.inputs.MongoConnectionInformationArgs.builder()
        .connectionString(connectionString?.applyValue({ args0 -> args0 }))
        .host(host?.applyValue({ args0 -> args0 }))
        .password(password?.applyValue({ args0 -> args0 }))
        .port(port?.applyValue({ args0 -> args0 }))
        .useSsl(useSsl?.applyValue({ args0 -> args0 }))
        .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MongoConnectionInformationArgs].
 */
@PulumiTagMarker
public class MongoConnectionInformationArgsBuilder internal constructor() {
    private var connectionString: Output<String>? = null

    private var host: Output<String>? = null

    private var password: Output<String>? = null

    private var port: Output<Int>? = null

    private var useSsl: Output<Boolean>? = null

    private var userName: Output<String>? = null

    /**
     * @param value ConnectionString to connect to Mongo.
     */
    @JvmName("ocfflkjgssdaajee")
    public suspend fun connectionString(`value`: Output<String>) {
        this.connectionString = value
    }

    /**
     * @param value Host of mongo connection.
     */
    @JvmName("pvpurbtfylddqckw")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Password to connect to Mongo.
     */
    @JvmName("ehmbmtrgytvnbman")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value Port of mongo connection.
     */
    @JvmName("ejocgubmtgrhdkjp")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Whether to UseSsl or UseTls to connect to Mongo. Default is true.
     */
    @JvmName("mqivqxvoigjvjgvy")
    public suspend fun useSsl(`value`: Output<Boolean>) {
        this.useSsl = value
    }

    /**
     * @param value User name to connect to Mongo.
     */
    @JvmName("vbhuxsnngmoqplle")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value ConnectionString to connect to Mongo.
     */
    @JvmName("hqfmsollrymsynly")
    public suspend fun connectionString(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionString = mapped
    }

    /**
     * @param value Host of mongo connection.
     */
    @JvmName("nfxgpxtdskcrqbxl")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Password to connect to Mongo.
     */
    @JvmName("cxydbqqccgxrdnyx")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Port of mongo connection.
     */
    @JvmName("jokdppfvhxctfpvq")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Whether to UseSsl or UseTls to connect to Mongo. Default is true.
     */
    @JvmName("cenmkmrtrdkshvdf")
    public suspend fun useSsl(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useSsl = mapped
    }

    /**
     * @param value User name to connect to Mongo.
     */
    @JvmName("ifucuelfjndcptvf")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): MongoConnectionInformationArgs = MongoConnectionInformationArgs(
        connectionString = connectionString,
        host = host,
        password = password,
        port = port,
        useSsl = useSsl,
        userName = userName,
    )
}
